/* led8x8_blinkheart
 *  
 * Ebben a mintaprogramban egy szívet villogtatunk 
 * egy 8×8-as LED mátrix felhasználásával. 
 * 
 * A program jelenlegi formájában az 1088AS 8x8 LED
 * kijelzőhöz készült. Fordított polaritású (pl. 1088BS)
 * kijelző esetén a rON, rOFF, CON, cOFF konstansokat
 * logikailag negálni kell (0 helyett 1, 1 helyett 0)
 * 
 * A kijelző bekötése: 1 - D03, 2 - D12, 3 - D11, 4 - D10,   
 * 5 - A2, 6 - A3, 7 - A4, 8 - A5, 9 - D2, 10 - D3, 11 - D4,
 * 12 - D5, 13 - D6, 14 - D7, 15 - D8, 16 - D9
 * 
 * A program eredetijének forrása:
 * http://osoyoo.com/2017/07/15/arduino-lesson-8x8-led-matrix/
 * 
 * A programot átdolgozta: Cserny István, 2020. Jan 3.
 */
#define rON  0     // sor aktiválás (1088AS esetén katód:0)
#define rOFF 1     // sor deaktiválás
#define cON  1     // oszlop aktiválás (1088AS esetén anód:1)
#define cOFF 0     // oszlop deaktiválás

int row[] = {2, 7, A5, 5, 13, A4, 12, A2}; // 9,14,8,12,1,7,2,5 
int col[] = {6, 11, 10, 3, A3, 4, 8, 9};   // 13,3,4,10,6,11,15,16

unsigned char biglove[8][8] =             //nagy "szív"
{
  0, 0, 0, 0, 0, 0, 0, 0,
  0, 1, 1, 0, 0, 1, 1, 0,
  1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1,
  1, 1, 1, 1, 1, 1, 1, 1,
  0, 1, 1, 1, 1, 1, 1, 0,
  0, 0, 1, 1, 1, 1, 0, 0,
  0, 0, 0, 1, 1, 0, 0, 0,
};

unsigned char smalllove[8][8] =           //kicsi "szív"
{
  0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 1, 0, 0, 1, 0, 0,
  0, 1, 1, 1, 1, 1, 1, 0,
  0, 1, 1, 1, 1, 1, 1, 0,
  0, 0, 1, 1, 1, 1, 0, 0,
  0, 0, 0, 1, 1, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0,
};

void setup() {
  for (int i = 0; i < 8; i++) {
    pinMode(row[i], OUTPUT);             // sor vezérlő kimenetek
    pinMode(col[i], OUTPUT);             // oszlop vezérlő kimenetek
  }
}

void loop() {
  for (int i = 0 ; i < 1000 ; i++) {
    Display(biglove);                   //Display the "Big Heart"
  }
  for (int i = 0 ; i < 500 ; i++) {
    Display(smalllove);                 //Display the "small Heart"
  }
}

//--- Megjelenítés (a kép felvillantása) -------
void Display(unsigned char dat[8][8]) {
  for (int c = 0; c < 8; c++) {         // Sorra vesszük az oszlopokat
    digitalWrite(col[c], cON);          // Aktuális oszlop aktiválása  
    for (int r = 0; r < 8; r++) {       // Sorra vesszük a sorokat
      digitalWrite(row[r],dat[r][c]^rOFF); // Képpont felvillantása
      digitalWrite(row[r],rOFF);
    }
    digitalWrite(col[c], cOFF);         // oszlop deaktiválása
  }
}
