/* led8x8_scrolltext.ino
 *  
 * Szöveg görgetés egy 8x8 LED mátrixon
 * A program jelenlegi formájában az 1088AS 8x8 LED
 * kijelzőhöz készült. Fordított polaritású (pl. 1088BS)
 * kijelző esetén a rON, rOFF, CON, cOFF konstansokat
 * logikailag negálni kell (0 helyett 1, 1 helyett 0)
 * 
 * A kijelző bekötése: 1 - D03, 2 - D12, 3 - D11, 4 - D10,   
 * 5 - A2, 6 - A3, 7 - A4, 8 - A5, 9 - D2, 10 - D3, 11 - D4,
 * 12 - D5, 13 - D6, 14 - D7, 15 - D8, 16 - D9
 *
 */

#include "font6x8.h"

#define rON  0     // sor aktiválás (1088AS esetén katód:0)
#define rOFF 1     // sor deaktiválás
#define cON  1     // oszlop aktiválás (1088AS esetén anód:1)
#define cOFF 0     // oszlop deaktiválás
int row[] = {2,7,A5,5,13,A4,12,A2};  // 9,14,8,12,1,7,2,5
int col[] = {6,11,10,3,A3,4,8,9};    // 13,3,4,10,6,11,15,16
byte pixels[8];

//--- Megjelenítés (a kép felvillantása) -------
void refreshScreen() {
  for (int c = 0; c < 8; c++) {      // Sorra vesszük az oszlopokat
    digitalWrite(col[c], cON);       // Aktuális oszlop aktiválása
    byte thisByte = pixels[c];       // Pixel oszlop elővétele
    for (int r = 0; r < 8; r++) {    // Sorra vesszük a sorokat
      if (bitRead(thisByte,r)) {     // Ha a pixel értéke = 1
        digitalWrite(row[r],rON);    // Képpont felvillantása
      }
      digitalWrite(row[r],rOFF);
    }
    digitalWrite(col[c],cOFF);       // oszlop deaktiválása
  }
}

//--- Mátrix görgetés balra --------
void scrollLeft(byte data) {
  for (byte i = 0; i < 7; i++) {
    pixels[i] = pixels[i + 1];       // Minden pixeloszlop balra lép
  }
  pixels[7] = data;                  // Az utolsó oszlop az új adat
}

//--- Törli a pixel mátrixot -------
void clearMatrix() {
  for (byte i = 0; i < 8; i++) {
    pixels[i] = 0;
  }
}

//--- Egy karakter kiírása ---------
void writeChar(char ch) {
  ch -= 32;                          // Szóköz az első karakter
  for (int line = 0; line < 6; line++) {
    scrollLeft(font6x8[ch][line]);   // Egy pontoszlop beszúrása jobbról
    for(int i=0; i<250; i++) { 
      refreshScreen();               // Képfrissítés 250-szer
    }
  }
}

//--- Szöveg kiírása karakterenként ----
void showText(char *s) {
  while (*s) {
    writeChar(*s);
    s++;
  }
}

void setup() {
  for (int i = 0; i < 8; i++) {
    pinMode(row[i], OUTPUT);         // sor vezérlő kimenetek
    pinMode(col[i], OUTPUT);         // oszlop vezérlő kimenetek
  }
  clearMatrix();
}

void loop() {
  showText("Szia, Pista vagyok. ");
  showText("LED8x8 scrolltext example  ");
  clearMatrix();
}
